==> atlaslib_ecmwf-0.41.dev1-cp310-cp310-manylinux_2_28_x86_64.whl: atlaslib_ecmwf/include/atlas/atlas_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ATLAS_ecbuild_config_h
#define ATLAS_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.9.1"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.9.1"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/src/ecbuild/cmake"
#endif

/* config info */

#define ATLAS_OS_NAME          "Linux-4.18.0-372.26.1.el8_6.x86_64"
#define ATLAS_OS_BITS          64
#define ATLAS_OS_BITS_STR      "64"
#define ATLAS_OS_STR           "linux.64"
#define ATLAS_OS_VERSION       "4.18.0-372.26.1.el8_6.x86_64"
#define ATLAS_SYS_PROCESSOR    "x86_64"

#define ATLAS_BUILD_TIMESTAMP  "20250228083105"
#define ATLAS_BUILD_TYPE       "RelWithDebInfo"

#define ATLAS_C_COMPILER_ID      "GNU"
#define ATLAS_C_COMPILER_VERSION "13.3.1"

#define ATLAS_CXX_COMPILER_ID      "GNU"
#define ATLAS_CXX_COMPILER_VERSION "13.3.1"

#define ATLAS_C_COMPILER       "/opt/rh/gcc-toolset-13/root/usr/bin/cc"
#define ATLAS_C_FLAGS          " -pipe -O2 -g -DNDEBUG"

#define ATLAS_CXX_COMPILER     "/opt/rh/gcc-toolset-13/root/usr/bin/c++"
#define ATLAS_CXX_FLAGS        " -pipe -Wall -Wextra -Wno-unused-parameter -Wno-sign-compare -O2 -g -DNDEBUG"

/* Needed for finding per package config files */

#define ATLAS_INSTALL_DIR       "/tmp/atlas/target/atlas"
#define ATLAS_INSTALL_BIN_DIR   "/tmp/atlas/target/atlas/bin"
#define ATLAS_INSTALL_LIB_DIR   "/tmp/atlas/target/atlas/lib64"
#define ATLAS_INSTALL_DATA_DIR  "/tmp/atlas/target/atlas/share/atlas"

#define ATLAS_DEVELOPER_SRC_DIR "/proj"
#define ATLAS_DEVELOPER_BIN_DIR "/tmp/atlas/build"

/* Fortran support */

#if 0

#define ATLAS_Fortran_COMPILER_ID      ""
#define ATLAS_Fortran_COMPILER_VERSION ""

#define ATLAS_Fortran_COMPILER ""
#define ATLAS_Fortran_FLAGS    ""

#endif

#endif /* ATLAS_ecbuild_config_h */

==> atlaslib_ecmwf-0.41.1.dev0-cp310-cp310-manylinux_2_28_x86_64.whl: atlaslib_ecmwf/include/atlas/atlas_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ATLAS_ecbuild_config_h
#define ATLAS_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.9.1"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.9.1"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "/src/ecbuild/cmake"
#endif

/* config info */

#define ATLAS_OS_NAME          "Linux-4.18.0-372.26.1.el8_6.x86_64"
#define ATLAS_OS_BITS          64
#define ATLAS_OS_BITS_STR      "64"
#define ATLAS_OS_STR           "linux.64"
#define ATLAS_OS_VERSION       "4.18.0-372.26.1.el8_6.x86_64"
#define ATLAS_SYS_PROCESSOR    "x86_64"

#define ATLAS_BUILD_TIMESTAMP  "20250306141944"
#define ATLAS_BUILD_TYPE       "RelWithDebInfo"

#define ATLAS_C_COMPILER_ID      "GNU"
#define ATLAS_C_COMPILER_VERSION "13.3.1"

#define ATLAS_CXX_COMPILER_ID      "GNU"
#define ATLAS_CXX_COMPILER_VERSION "13.3.1"

#define ATLAS_C_COMPILER       "/opt/rh/gcc-toolset-13/root/usr/bin/cc"
#define ATLAS_C_FLAGS          " -pipe -O2 -g -DNDEBUG"

#define ATLAS_CXX_COMPILER     "/opt/rh/gcc-toolset-13/root/usr/bin/c++"
#define ATLAS_CXX_FLAGS        " -pipe -Wall -Wextra -Wno-unused-parameter -Wno-sign-compare -O2 -g -DNDEBUG"

/* Needed for finding per package config files */

#define ATLAS_INSTALL_DIR       "/tmp/atlas/target/atlas"
#define ATLAS_INSTALL_BIN_DIR   "/tmp/atlas/target/atlas/bin"
#define ATLAS_INSTALL_LIB_DIR   "/tmp/atlas/target/atlas/lib64"
#define ATLAS_INSTALL_DATA_DIR  "/tmp/atlas/target/atlas/share/atlas"

#define ATLAS_DEVELOPER_SRC_DIR "/src/proj"
#define ATLAS_DEVELOPER_BIN_DIR "/tmp/atlas/build"

/* Fortran support */

#if 0

#define ATLAS_Fortran_COMPILER_ID      ""
#define ATLAS_Fortran_COMPILER_VERSION ""

#define ATLAS_Fortran_COMPILER ""
#define ATLAS_Fortran_FLAGS    ""

#endif

#endif /* ATLAS_ecbuild_config_h */
